library(growth)

y <- as.matrix(read.table("pituitar.dat",skip=5))
colnames(y) <- c("Age 8","Age 10","Age 12","Age 14")
x <- cbind(rep(1,nrow(y)),c(rep(0,11),rep(1,16)))
colnames(x) <- c("(Intercept)","Sex")
sex <- c(rep(0,11),rep(1,16))
times <- c(8,10,12,14)

if(interactive()){
postscript("pituprof.eps",height=5)
par(mfrow=c(1,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(restovec(y,times=times),nind=1:11,xlab="Age",ylab="Distance (mm)",
	ylim=c(0,35),main="Girls",lty=1,xaxt="n",yaxt="n")
axis(1,at=c(8,10,12,14))
axis(2,at=c(0,10,20,30))
plot(restovec(y,times=times),nind=12:27,xlab="Age",ylab="",
	ylim=c(0,35),main="Boys",lty=1,xaxt="n",yaxt="n")
axis(1,at=c(8,10,12,14))
axis(2,at=c(0,10,20,30))
dev.off()
postscript("pituitar.eps",width=5,height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(times,c(mean(y[1:11,1]),mean(y[1:11,2]),mean(y[1:11,3]),mean(y[1:11,4])),
	type="l",xaxt="n",yaxt="n",ylim=c(0,35),xlab="Age",
	ylab="Distance (mm)")
axis(1,at=c(8,10,12,14))
axis(2,at=c(0,10,20,30))
points(times,c(mean(y[1:11,1]),mean(y[1:11,2]),mean(y[1:11,3]),
	mean(y[1:11,4])),pch=20)
lines(times,c(mean(y[12:27,1]),mean(y[12:27,2]),mean(y[12:27,3]),
	mean(y[12:27,4])),lty=2)
points(times,c(mean(y[12:27,1]),mean(y[12:27,2]),mean(y[12:27,3]),
	mean(y[12:27,4])),pch=20)
legend(12,20,legend=c("Girls","Boys"),lty=c(1,2),bty="n")
dev.off()
}

# (standard errors wrong in book)
# Sex effect
print(z1 <- potthoff(y,x,torder="f",ccov=x))
z1$pcov
# No sex effect
print(z2 <- potthoff(y,x,torder="f"))
z2$pcov
# No time trend
print(z3 <- potthoff(y,x,torder=0,ccov=x))
z3$pcov
# Linear time trend
print(z4 <- potthoff(y,x,torder=1,ccov=x,orthog=F,times=c(-3,-1,1,3)))
z4$pcov
# Random effect
reps <- rmna(restovec(y,times=times),ccov=(tcctomat(sex)))
carma(reps,ccov=~sex,torder=1,pre=1,pos=c(1,1))
