library(growth)
library(repeated)

y <- as.matrix(read.table("pituitar.dat",skip=5))
colnames(y) <- c("Age 8","Age 10","Age 12","Age 14")
x <- cbind(rep(1,nrow(y)),c(rep(0,11),rep(1,16)))
colnames(x) <- c("(Intercept)","Sex")
sex <- c(rep(0,11),rep(1,16))
times <- c(8,10,12,14)

if(interactive()){
postscript("pituprof.eps",height=5)
par(mfrow=c(1,2),font.main=1)
plot(c(8,10,12,14),y[1,],xlab="Age",ylab="Distance (mm.)",
	ylim=c(0,35),xaxt="n",type="l",main="Girls")
axis(1,at=c(8,10,12,14))
for(i in 2:11)lines(c(8,10,12,14),y[i,])
plot(c(8,10,12,14),y[12,],xlab="Age",ylab="",
	ylim=c(0,35),xaxt="n",type="l",main="Boys")
axis(1,at=c(8,10,12,14))
for(i in 13:27)lines(c(8,10,12,14),y[i,])
}

print("Sex effect")
potthoff(y,x,torder="f",ccov=x)
print("No time trend")
potthoff(y,x,torder=0,ccov=x)
print("Linear time trend")
potthoff(y,x,torder=1,ccov=x)
potthoff(y,x,torder=1,ccov=x,orthog=F,times=c(-3,-1,1,3))
print("Quadratic time trend")
potthoff(y,x,torder=2,ccov=x)
print("Cubic time trend")
potthoff(y,x,torder=3,ccov=x)
print("No sex effect")
potthoff(y,x,torder="f")
print("No time trend")
potthoff(y,x,torder=0)
print("Linear time trend")
potthoff(y,x,torder=1)

y <- restovec(y,times=times)
carma(y)
carma(y,torder=2)
carma(y,ccov=sex,torder=1)
carma(y,ccov=sex,torder=2)
carma(y,ccov=sex,torder=2,interact=2)
carma(y,ccov=sex,torder=1,pre=1,pos=c(1,1))
carma(y,ccov=sex,torder=2,pre=1,pos=c(1,1))

if(interactive()){
postscript("pituitar.eps",width=5,height=5)
plot(c(8,10,12,14),c(mean(y[1:11,1]),mean(y[1:11,2]),mean(y[1:11,3]),
	mean(y[1:11,4])),type="l",ylim=c(16,28),xlab="Age",ylab="Distance")
points(c(8,10,12,14),c(mean(y[1:11,1]),mean(y[1:11,2]),mean(y[1:11,3]),
	mean(y[1:11,4])),pch=20)
lines(c(8,10,12,14),c(mean(y[12:27,1]),mean(y[12:27,2]),mean(y[12:27,3]),
	mean(y[12:27,4])),lty=2)
points(c(8,10,12,14),c(mean(y[12:27,1]),mean(y[12:27,2]),mean(y[12:27,3]),
	mean(y[12:27,4])),pch=20)
#points(rep(c(8,10,12,14),11),t(as.matrix(y[1:11,])),pch=1)
#points(rep(c(8,10,12,14),16),t(as.matrix(y[12:27,])),pch=3)
legend(12,20,legend=c("Girls","Boys"),lty=c(1,2),bty="n")
}

print(s1 <- carma(y,ccov=sex,torder=1,inter=1,arma=c(1,0,0),parma=1))
print(s2 <- carma(y,ccov=sex,torder=1,inter=1,arma=c(2,0,0),
	parma=c(-0.7,-0.5)))
print(s3 <- carma(y,ccov=sex,torder=1,inter=1,arma=c(3,0,0),
	parma=c(4.5,-0.1,-1.8)))
print(u1 <- carma(y,ccov=sex,torder=3,inter=3,arma=c(1,0,0),parma=1))
print(u3 <- carma(y,ccov=sex,torder=3,inter=3,arma=c(3,0,0),
	parma=c(4.5,-0.1,-1.8)))
print(v1 <- carma(y,ccov=sex,torder=1,inter=1,arma=c(2,1,0),parma=c(-2,2,-1)))

tt <- matrix(rep(times,27)-11,ncol=4,byrow=T)
carma(y)
kalseries(y,intensity="normal",dep="independence",psh=5,preg=22)

carma(y,arma=c(1,0,0),par=0)
kalseries(y,intensity="normal",dep="serial",pdep=0.5,psh=5,preg=23)
kalseries(y,intensity="normal",dep="Markov",pdep=0.5,psh=5,preg=23)
carma(y,arma=c(1,0,0),par=0,ccov=sex)
kalseries(y,intensity="normal",dep="serial",pdep=0.5,psh=5,
	ccov=sex,preg=c(23,2))
kalseries(y,intensity="normal",dep="Markov",pdep=0.99,psh=5,
	ccov=sex,preg=c(23,2))
carma(y,arma=c(1,0,0),par=0,ccov=sex,torder=1)
#kalseries(y,intensity="normal",dep="serial",pdep=0.5,psh=2.9,
#	ccov=sex,preg=c(22,2),tvc=tt,ptvc=0,pinit=0.8)
kalseries(y,intensity="normal",dep="serial",pdep=0.5,psh=2.9,
	ccov=sex,preg=c(22,2,0),torder=1,pinit=0.8)
kalseries(y,intensity="normal",dep="Markov",pdep=0.5,psh=2.9,
	ccov=sex,preg=c(22,2,0),torder=1,pinit=0.8)
carma(y,arma=c(1,0,0),par=0,ccov=sex,torder=1,int=1)
kalseries(y,intensity="normal",dep="serial",pdep=0.95,psh=2.15,
	ccov=sex,preg=c(22,2.4,0.43,0.33),torder=1,int=1,pinit=0.66)

carma(y,ccov=sex,torder=1,trans="sqrt")
kalseries(y,intensity="normal",dep="independence",psh=0.1,ccov=sex,
	preg=c(4,0.25),tvc=tt,ptvc=0.13,pinit=0.1,trans="sqrt")
carma(y,arma=c(1,0,0),par=0,ccov=sex,torder=1,trans="sqrt")
kalseries(y,intensity="normal",dep="serial",pdep=0.9,psh=0.1,ccov=sex,
	preg=c(4,0.23),tvc=tt,ptvc=0.07,pinit=0.12,trans="sqrt")

carma(y,pre=0.5,pos=c(1,1))
kalseries(y,intensity="normal",dep="frailty",preg=23,psh=5)
carma(y,pre=0.5,pos=c(1,1),ccov=sex)
kalseries(y,intensity="normal",dep="frailty",psh=5,ccov=sex,preg=c(23,2))
carma(y,pre=0.5,pos=c(1,1),ccov=sex,torder=1)
kalseries(y,intensity="normal",dep="frailty",psh=5,
	ccov=sex,preg=c(23,2),tvc=tt,ptvc=0)

carma(y,pre=0.5,pos=c(1,1),ccov=sex,torder=1,trans="log")
#kalseries(y,intensity="log normal",dep="frailty",psh=0.004,
#	ccov=sex,preg=c(3.1,0.1),tvc=tt,ptvc=0)
kalseries(y,intensity="log normal",dep="frailty",psh=0.004,
	ccov=sex,preg=c(3.1,0.1,0),torder=1)
carma(y,pre=0.5,pos=c(1,1),ccov=sex,torder=1,int=1,trans="log")
kalseries(y,intensity="log normal",dep="frailty",psh=0.004,
	ccov=sex,preg=c(3.1,0.1,0.03,0),torder=1,int=1)

carma(y,pre=0.5,pos=c(1,1),ccov=sex,torder=1,trans="sqrt")
kalseries(y,intensity="normal",dep="frailty",psh=0.02,
	ccov=sex,preg=c(4.75,0.2),tvc=tt,ptvc=0,trans="sqrt")

kalseries(y,intensity="Weibull",dep="frailty",psh=5,
	ccov=sex,preg=c(23,2),tvc=tt,ptvc=0)
kalseries(y,intensity="logistic",dep="frailty",psh=5,
	ccov=sex,preg=c(23,2),tvc=tt,ptvc=0)
kalseries(y,intensity="Cauchy",dep="frailty",psh=5,
	ccov=sex,preg=c(23,2),tvc=tt,ptvc=0)
