options(contrasts = c("contr.sum", "contr.poly"))
library(growth)
library(repeated)

y <- as.matrix(read.table("ramus.dat",skip=4))
times <- c(8,8.5,9,9.5)
yy <- as.vector(t(y))
tt <- rep(times,20)
resp <- restovec(y,times=times)

if(interactive()){
postscript("ramus.eps",width=5,height=5)
plot(times,y[1,],ylim=c(44,56),xlim=c(8,9.5),ylab="Ramus height",xlab="Age",
	type="l")
for(i in 2:20)lines(times,y[i,])
}

carma(resp)
carma(resp,torder=1)
carma(resp,torder=1,pre=5,pos=c(1,1))
carma(resp,torder=1,pre=c(5.5,2),pos=rbind(c(1,1),c(2,2)))
carma(resp,torder=1,times=c(-3,-1,1,3),pre=c(5.5,1),pos=rbind(c(1,1),c(2,2)))

glmm(yy~tt,nest=gl(20,4,80))
# underflow
#gnlmm(yy,"normal",nest=gl(20,4,80),pmu=c(33.7,1.9),mu=~tt,psh=-0.34,
#	psd=1.9,points=3)

kalseries(resp,intensity="normal",dep="independence",preg=50,psh=7.6,pinit=1.5)
carma(resp,arma=c(1,0,0),par=0)
kalseries(resp,intensity="normal",dep="serial",pdep=0.6,preg=50,psh=7.3)
kalseries(resp,intensity="normal",dep="Markov",pdep=0.6,preg=50,psh=3)
carma(resp,pre=1,pos=c(1,1))
kalseries(resp,intensity="normal",dep="frailty",preg=50,psh=7.3)

time <- rep(c(-3,-1,1,3),20)
subject <- gl(20,4,80)
summary(z1 <- glm(yy~subject/time))
summary(z2 <- glm(yy~subject+time))
summary(z3 <- glm(yy~subject))
summary(z4 <- glm(yy~1))
summary(z5 <- glm(yy~time))
summary(z6 <- glm(yy~as.factor(time)))

ss <- double(4)
ss[1] <- z4$dev-z3$dev
ss[2] <- z3$dev-z2$dev
ss[3] <- z2$dev-z1$dev
ss[4] <- z1$dev
d.f <- c(19,1,19,40)
ff <- rep(1,4)
ff[2] <- ss[2]*d.f[3]/ss[3]/d.f[2]
anova.table <- cbind(ss,d.f,ss/d.f,ff)
colnames(anova.table) <- c("SS","df","MSS","F")
rownames(anova.table) <- c("Subjects","Linear time","Subjects/Linear time",
	"Residual")
anova.table

print(a <- (ss[1]/d.f[1]-ss[4]/d.f[4])/4)
print(b <- (ss[3]/d.f[3]-ss[4]/d.f[4])/sum(c(-3,-1,1,3)^2))
delta <- diag(c(a,b))

v <- cbind(rep(1,4),c(-3,-1,1,3))
print(s0 <- v%*%delta%*%t(v)+ss[4]/d.f[4]*diag(4))
res <- matrix((yy-z5$fit),ncol=4,byrow=T)
print(s1 <- t(res)%*%res/20)
res2 <- matrix((yy-z6$fit),ncol=4,byrow=T)
print(s2 <- t(res2)%*%res2/20)

20*(4*(1+log(2*pi))+log(det(s0)))/2+2+3
20*(4*(1+log(2*pi))+log(det(s1)))/2+2+10
20*(4*(1+log(2*pi))+log(det(s2)))/2+4+10

# REML estimate
a <- (ss[3]+ss[4])/(d.f[3]+d.f[4])
b <- (ss[1]/d.f[1]-a)/4
print(s3 <- matrix(rep(b,16),nrow=4)+diag(4)*a)
# MLE
print(a <- (ss[3]+ss[4])/60)
b <- (ss[1]/20-a)/4
print(s3 <- matrix(rep(b,16),nrow=4)+diag(4)*a)
20*(4*(1+log(2*pi))+log(det(s3)))/2+2+2

# REML estimate
print(a <- (ss[1]+ss[3]+ss[4])/(d.f[1]+d.f[3]+d.f[4]))
# MLE
print(a <- (ss[1]+ss[3]+ss[4])/80)
20*(4*(1+log(2*pi))+log(det(diag(4)*a)))/2+2+1
